@@ -53,7 +53,7 @@ HTTP_OK = 200
 HTTP_ERROR = 500
 
 try:
-    import hpmudext
+    hpmudext=utils.import_ext('hpmudext')
 except ImportError:
     if not os.getenv("HPLIP_BUILD"):
         log.error("HPMUDEXT could not be loaded. Please check HPLIP installation.")
@@ -357,18 +357,9 @@ def makeURI(param, port=1):
     else: # Try Zeroconf hostname
         log.debug("Trying ZC hostname %s" % param)
 
-        result_code, uri = hpmudext.make_zc_uri(param, port)
+        if ( len (param) < 251):
 
-        if result_code == hpmudext.HPMUD_R_OK and uri:
-            uri = to_string_utf8(uri)
-            log.debug("Found: %s" % uri)
-            found = True
-            cups_uri = uri
-
-        else: # Try DNS hostname
-            log.debug("Device not found using mDNS hostname. Trying with DNS hostname %s" % param)
-
-            result_code, uri = hpmudext.make_net_uri(param, port)
+            result_code, uri = hpmudext.make_zc_uri(param, port)
 
             if result_code == hpmudext.HPMUD_R_OK and uri:
                 uri = to_string_utf8(uri)
@@ -376,8 +367,20 @@ def makeURI(param, port=1):
                 log.debug("Found: %s" % uri)
                 found = True
                 cups_uri = uri
-            else:
-                log.debug("Not found.")
+
+            else: # Try DNS hostname
+                log.debug("Device not found using mDNS hostname. Trying with DNS hostname %s" % param)
+
+                result_code, uri = hpmudext.make_net_uri(param, port)
+
+                if result_code == hpmudext.HPMUD_R_OK and uri:
+                    uri = to_string_utf8(uri)
+                    uri = uri.replace("ip=","hostname=")
+                    log.debug("Found: %s" % uri)
+                    found = True
+                    cups_uri = uri
+                else:
+                    log.debug("Not found.")
 
     if not found:
         log.debug("Trying serial number %s" % param)
@@ -519,15 +522,9 @@ def probeDevices(bus=DEFAULT_PROBE_BUS, timeout=10,
                             model = models.normalizeModelName(device_id.get('MDL', '?UNKNOWN?'))
 
                             if num_ports_on_jd == 1:
-                                if net_search == 'slp':
-                                    device_uri = 'hp:/net/%s?ip=%s' % (model, ip)
-                                else:
-                                    device_uri = 'hp:/net/%s?zc=%s' % (model, hn)
+                                device_uri = 'hp:/net/%s?ip=%s' % (model, ip)
                             else:
-                                if net_search == 'slp':
-                                    device_uri = 'hp:/net/%s?ip=%s&port=%d' % (model, ip, (port + 1))
-                                else:
-                                    device_uri = 'hp:/net/%s?zc=%s&port=%d' % (model, hn, (port + 1))
+                                device_uri = 'hp:/net/%s?ip=%s&port=%d' % (model, ip, (port + 1))
 
                             include = True
                             mq = queryModelByModel(model)
@@ -1009,6 +1006,7 @@ class Device(object):
                 raise Error(ERROR_DEVICE_NOT_FOUND)
 
         self.device_uri = device_uri
+        self.printer_name = printer_name
         self.callback = callback
         self.device_type = DEVICE_TYPE_UNKNOWN
 
@@ -1693,7 +1691,7 @@ class Device(object):
 
             elif status_type == STATUS_TYPE_IPP:
                 log.debug("Type 12: IPP")
-                status_block = status.StatusTypeIPP(self.device_uri)
+                status_block = status.StatusTypeIPP(self.device_uri,self.printer_name)
 
             else:
                 log.error("Unimplemented status type: %d" % status_type)
@@ -2145,6 +2143,16 @@ class Device(object):
             elif END_OF_DATA == temp_buf.getvalue():   # Chunked data end
                     break
 
+    def readLEDMAllData(dev, func, reply, timeout=6):
+        '''
+        Read any leftover response data from the previous session.
+        We read and disregard all such leftover data here to have a clean new session.
+        If we are getting a blank responses that means there is no more junk data. 
+        '''
+        while True:
+            bytes_read = func(1024, reply, timeout)
+            if bytes_read == 0:
+                break
 
 
     def __readChannel(self, opener, bytes_to_read, stream=None,
